@@ -997,11 +997,10 @@ class RemoteJob(object):
         if bulk_data:
             try:
                 response = self._conn._post_bulk(bulk_data, self._job_id)
-            except ShoojuApiError:
-                # flush cache to avoid re-raising the same exceptions, but only for ShoojuApiErrors
+            finally:
+                # always flush cache
                 self._values = {}
                 self._cur_batch_size = 0
-                raise
         self._run_post_submit_hooks(response)
         return True
 
